import * as core from 'aws-cdk-lib';
import { aws_vpclattice } from 'aws-cdk-lib';
import { FixedResponse, Protocol, ProtocolVersion } from './target';
export interface TargetGroupHealthCheckProps {
    /**
     * Enable this Health Check
     * @default true
     */
    readonly enabled?: boolean | undefined;
    /**
     * Health Check Interval
     * @default 30 seconds
     */
    readonly healthCheckInterval?: core.Duration | undefined;
    /**
     * TimeOut Period
     * @default 5 seconds
     */
    readonly healthCheckTimeout?: core.Duration | undefined;
    /**
     * Number of Healthy Responses before Target is considered healthy
     * @default 2
     */
    readonly healthyThresholdCount?: number | undefined;
    /**
     * Check based on Response from target
     * @default 200 OK
     */
    readonly matcher?: FixedResponse | undefined;
    /**
     * Path to use for Health Check
     * @default '/'
     */
    readonly path?: string | undefined;
    /**
     * Port to use for Health Check
     * @default 443
     */
    readonly port?: number | undefined;
    /**
     * Protocol to use for Health Check
     * @default HTTPS
     */
    readonly protocol?: Protocol | undefined;
    /**
     * Protocol to use for Health Check
     * @default HTTP2
     */
    readonly protocolVersion?: ProtocolVersion | undefined;
    /**
     * Number of unhealty events before Target is considered unhealthy
     * @default 1
     */
    readonly unhealthyThresholdCount?: number | undefined;
}
/**
 * Create a Health Check for a target
 */
export declare abstract class HealthCheck {
    /**
     * A Health Check configuration object for a target
     * @param props
     * @returns HealthCheck
     */
    static check(props: TargetGroupHealthCheckProps): HealthCheck;
    /**
     * health check is enabled.
     */
    abstract readonly enabled: boolean;
    /**
     * healthCheck Interval
     */
    abstract readonly healthCheckInterval: core.Duration;
    /**
     * HealthCheck Timeout
     */
    abstract readonly healthCheckTimeout: core.Duration;
    /**
     * Target Match reponse
     */
    abstract readonly matcher: aws_vpclattice.CfnTargetGroup.MatcherProperty | undefined;
    /**
     * Path to check
     */
    abstract readonly path: string;
    /**
     * Port to check
     */
    abstract readonly port: number;
    /** Protocol
     *
     */
    abstract readonly protocol: string;
    /**
     * HTTP Protocol Version
     */
    abstract readonly protocolVersion: string;
    /**
     * Unhealthy Threshold Count
     */
    abstract readonly unhealthyThresholdCount: number;
    /**
     * Healthy Threshold Count
     */
    abstract readonly healthyThresholdCount: number;
    protected constructor();
}
