import * as core from 'aws-cdk-lib';
import * as constructs from 'constructs';
import { ITarget } from './index';
/**
 * Create a vpc lattice TargetGroup.
 * Implemented by `TargetGroup`.
 */
export interface ITargetGroup extends core.IResource {
    /**
     * The id of the target group
     */
    readonly targetGroupId: string;
    /**
     * The Arn of the target group
     */
    readonly targetGroupArn: string;
}
/**
 * Properties for a Target Group, Only supply one of instancetargets, lambdaTargets, albTargets, ipTargets
 */
export interface TargetGroupProps {
    /**
     * The name of the target group
     */
    readonly name: string;
    /**
     * Targets
     */
    readonly target: ITarget;
}
/**
 * Create a vpc lattice TargetGroup
 *
 */
export declare class TargetGroup extends core.Resource implements ITargetGroup {
    readonly targetGroupId: string;
    /**
     * The Arn of the targetGroup
     */
    readonly targetGroupArn: string;
    constructor(scope: constructs.Construct, id: string, props: TargetGroupProps);
}
export interface WeightedTargetGroup {
    /**
     * A target Group
     */
    readonly targetGroup: TargetGroup;
    /**
    * A weight for the target group.
    * @default 100
    */
    readonly weight?: number | undefined;
}
